@@ -310,8 +310,17 @@ def _file_exists(context, path):
     @gen.coroutine
     def key_exists():
         key = _key(context, path)
-        response = _head_object(context, context.s3_bucket, key)
-        print('key',response)
+        # response = _head_object(context, context.s3_bucket, key)
+        # print('key',response)
+        # return response
+
+        try:
+            response = yield _head_object(context, context.s3_bucket, key)
+        except HTTPClientError as exception:
+            if exception.response.code != 404:
+                raise HTTPServerError(exception.response.code, 'Error checking if S3 exists')
+            response = exception.response
+
         return response
 
     return False if _is_root(path) else (yield key_exists())
